@@ -88,6 +88,7 @@ class Sensor(Device):
 
 
 class PropertyIDs(Enum):
+    NOTIFICATION = "P1"
     ON = "P3"
     AVAILABLE = "P5"
     BRIGHTNESS = "P1501"  # From 0-100
@@ -161,9 +162,6 @@ class File:
         else:
             self.type = "Video"
 
-    def __repr__(self) -> str:
-        return "<File: {}, {}>".format(self.file_id, self.type)
-
 
 class Event:
     event_id: str
@@ -177,7 +175,6 @@ class Event:
     is_feedback_face: int
     is_feedback_person: int
     file_list: List[Dict[Any, Any]]
-    typed_file_list: List[File] = []
     event_params: Dict[Any, Any]
     recognized_instance_list: List[Any]
     tag_list: List[Any]
@@ -186,15 +183,18 @@ class Event:
     def __init__(self, dictionary: Dict[Any, Any]):
         for k, v in dictionary.items():
             setattr(self, k, v)
-        if len(self.file_list) > 0:
-            for file in self.file_list:
-                self.typed_file_list.append(File(file))
-
-    def __repr__(self) -> str:
-        return "<Event: {}, {}>".format(self.event_id, self.event_ts)
 
 
 class HMSStatus(Enum):
     DISARMED = 'disarmed'
     HOME = 'home'
     AWAY = 'away'
+
+
+
+
+
+
+
+
+
